@@ -598,6 +598,8 @@ class Lunar:
             fs = LunarUtil.OTHER_FESTIVAL[md]
             for f in fs:
                 arr.append(f)
+        if self.__solar.toYmd() == self.__jieQi["清明"].next(-1).toYmd():
+            arr.append("寒食节")
         return arr
 
     def getEightChar(self):
